@@ -7,7 +7,7 @@
 ******************************************************************************/
 
 /*
- * $Id: shorten.h,v 1.5 2002/01/28 01:16:52 jason Exp $
+ * $Id: shorten.h,v 1.7 2002/11/16 18:03:07 jason Exp $
  */
 
 #ifndef _SHORTEN_H
@@ -86,7 +86,8 @@ extern char *sys_errlist[];
 #define TYPE_AU3            9  /* lossless alaw                             */
 #define TYPE_ALAW          10  /* lossy alaw: internal conversion to linear */
 #define TYPE_RIFF_WAVE     11  /* Microsoft .WAV files                      */
-#define TYPE_EOF           12
+#define TYPE_AIFF          12  /* Apple .AIFF files                         */
+#define TYPE_EOF           13
 #define TYPE_GENERIC_ULAW 128
 #define TYPE_GENERIC_ALAW 129
 
@@ -206,10 +207,23 @@ extern void exit    PROTO ((int));
 
 /************************/
 /* defined in shorten.c */
+typedef struct Iff_Header Iff_Header;
 extern void  init_offset PROTO ((slong**, int, int, int));
 extern int   shorten     PROTO ((FILE*, FILE*, int, char**));
 extern ulong bytes_read;
 
+/*
+ * This structure contains an array of `char *' pointers to blocks
+ * of data to be coded verbatim. The structure itself will be
+ * dynamically allocated, as will the array of pointers, as will
+ * the blocks themselves.
+ */
+struct Iff_Header {
+  int nblocks, nblk_alloc;
+  uchar **blocks;
+  unsigned *blklen;
+};
+
 /**************************/
 /* defined in Sulawalaw.c */
 extern int Sulaw2lineartab[];
@@ -301,12 +315,17 @@ extern int dupfileinfo PROTO ((char*, char*));
 /*************************/
 /* defined in riffwave.c */
 
-typedef struct Riff_Wave_Header Riff_Wave_Header;
-Riff_Wave_Header *riff_wave_prochdr PROTO ((FILE *, int *, int *, slong *, int *));
-void              write_header      PROTO ((Riff_Wave_Header *, FILE *));
-void              free_header       PROTO ((Riff_Wave_Header *));
+Iff_Header *riff_wave_prochdr PROTO ((FILE *, int *, int *, slong *, int *));
+void              write_hdr         PROTO ((const uchar *, int, Iff_Header *));
+void              write_header      PROTO ((Iff_Header *, FILE *));
+void              free_header       PROTO ((Iff_Header *));
 void              verbatim_file     PROTO ((FILE *, FILE *));
 
+/*********************/
+/* defined in aiff.c */
+
+Iff_Header *aiff_prochdr PROTO ((FILE *, int *, int *, slong *, int *));
+
 /************************/
 /* defined in license.c */
 extern void license PROTO ((void));
