@@ -6,9 +6,13 @@
 *                                                                             *
 ******************************************************************************/
 
-/* 
-  set the atime and mtime of path1 to be the same as that of path0
-*/
+/*
+ * $Id: dupfinfo.c,v 1.4 2002/01/27 16:02:53 jason Exp $
+ */
+
+/*
+ * set the atime and mtime of path1 to be the same as that of path0
+ */
 
 #include <stdio.h>
 #include <sys/types.h>
