@@ -7,7 +7,7 @@
 ******************************************************************************/
 
 /*
- * $Id: shorten.c,v 1.14 2002/02/10 17:49:47 jason Exp $
+ * $Id: shorten.c,v 1.22 2003/01/11 01:28:15 jason Exp $
  */
 
 #ifdef _WINDOWS
@@ -416,7 +416,7 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
   int   quanterror = DEFAULT_QUANTERROR, minsnr = DEFAULT_MINSNR, nfilename;
   int   ulawZeroMerge = 0;
   slong  datalen = -1;
-  Riff_Wave_Header *wavhdr = NULL;
+  Iff_Header *wavhdr = NULL;
   char  *minusstr  = "-";
   extern char *hs_optarg;
   extern int   hs_optind;
@@ -517,7 +517,7 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
 
             PRINTF2("%s version %s: (c) 1992-1999 Tony Robinson and SoftSound Ltd\n",
             PACKAGE, VERSION);
-            PRINTF0("Seek extensions by Wayne Stielau; UNIX back-port by Jason Jordan\n");
+            PRINTF0("Seek extensions by Wayne Stielau; UNIX maintenance by Jason Jordan\n");
 /*
             PRINTF0("for more information see http://www.softsound.com/Shorten.html\n");
 */
@@ -530,9 +530,9 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
             PRINTF1("  -c %-5d number of channels\n", DEFAULT_NCHAN);
             PRINTF1("  -d %-5d number of bytes to discard before compression or decompression\n", DEFAULT_NDISCARD);
             PRINTF0("  -e       erase seek table appended to input file\n");
+            PRINTF0("  -h       help (this message)\n");
             PRINTF0("  -i       inquire as to whether a seek table is appended to input file\n");
             PRINTF0("  -k       append seek table information to existing shorten file\n");
-            PRINTF0("  -h       help (this message)\n");
             PRINTF0("  -l       print the license giving the distribution and usage conditions\n");
             PRINTF1("  -m %-5d number of past block for mean estimation\n",(FORMAT_VERSION < 2) ? DEFAULT_V0NMEAN : DEFAULT_V2NMEAN);
             PRINTF2("  -n %-5d minimum signal to noise ratio in dB (%d == lossless coding)\n",DEFAULT_MINSNR, DEFAULT_MINSNR);
@@ -541,7 +541,7 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
             PRINTF2("  -r %-5s maximum number of bits per sample (%s == lossless coding)\n",DEFAULT_MAXRESNSTR, DEFAULT_MAXRESNSTR);
             PRINTF0("  -s       generate seek table information in separate file [input file].skt\n");
             PRINTF0("  -S[name] generate seek table information in separate file given by [name]\n");
-            PRINTF0("  -t wav   specify the bit packing and byte ordering of the sample file from\n           {wav,ulaw,alaw,s8,u8,s16,u16,s16x,u16x,s16hl,u16hl,s16lh,u16lh}\n");
+            PRINTF0("  -t wav   specify the bit packing and byte ordering of the sample file from\n           {aiff,wav,ulaw,alaw,s8,u8,s16,u16,s16x,u16x,s16hl,u16hl,s16lh,u16lh}\n");
             PRINTF0("  -u       merge the two zero codes in ulaw files\n");
             PRINTF1("  -v %-5d format version number (2: no seek info; 3: default)\n", MAX_SUPPORTED_VERSION);
             PRINTF0("  -x       extract (all other options except -a, -d and -t are ignored)\n");
@@ -640,6 +640,8 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
             ftype = TYPE_U16LH;
           else if(!strcmp(hs_optarg, "wav"))
             ftype = TYPE_RIFF_WAVE;
+          else if(!strncmp(hs_optarg, "aiff", 3))
+            ftype = TYPE_AIFF;
           else
             usage_exit(1, "unknown file type: %s\n", hs_optarg);
           break;
@@ -703,7 +705,8 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
       break;
     case 1:
     {
-      int oldfilelen, newfilelen, suffixlen, maxlen;
+      int oldfilelen, newfilelen, suffixlen, maxlen, dots;
+      char *p;
 
       filenamei  = argv[argc - 1];
       filenamei_orig = filenamei;
@@ -715,6 +718,7 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
         maxlen = oldfilelen + suffixlen;
         tmpfilename = pmalloc((ulong) (maxlen + 1));
         strcpy(tmpfilename, filenamei);
+
         if (strcmp(tmpfilename,minusstr)) {
           if (newfilelen >= 0 &&
 #if defined(MSDOS) || defined(_WINDOWS)
@@ -722,9 +726,25 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
 #else
               !strcasecmp(tmpfilename + newfilelen, FILESUFFIX))
 #endif
-            strcpy(tmpfilename+newfilelen,WAVESUFFIX);
-          else
+          {
+            p = tmpfilename + oldfilelen - 1;
+            dots = 0;
+            while (dots < 2 && p >= tmpfilename && '/' != *p) {
+              if ('.' == *p)
+                dots++;
+              p--;
+            }
+
+            if (dots >= 2) {
+              *(tmpfilename+newfilelen) = 0;
+            }
+            else {
+              strcpy(tmpfilename+newfilelen,WAVESUFFIX);
+            }
+          }
+          else {
             strcat(tmpfilename,WAVESUFFIX);
+          }
         }
       }
       else {
@@ -740,9 +760,12 @@ int shorten(FILE *stdi, FILE *stdo,int argc,char **argv)
 #else
               !strcasecmp(tmpfilename + newfilelen, WAVESUFFIX))
 #endif
+          {
             strcpy(tmpfilename+newfilelen,FILESUFFIX);
-          else
+          }
+          else {
             strcat(tmpfilename,FILESUFFIX);
+          }
         }
       }
 
@@ -852,6 +875,42 @@ StartAgain:
   {
     float *maxresn;
     int   nread, nscan = 0, vbyte = MAX_VERSION + 1;
+    char  xiff[4];
+
+    /* read magic for AIFF or RIFF WAVE, or if not committed */
+    if(ftype == TYPE_EOF || ftype == TYPE_AIFF || ftype == TYPE_RIFF_WAVE)
+    {
+      if (4 != fread(xiff, sizeof(char), 4, filei))
+        usage_exit(1, "error reading magic from input file\n");
+    }
+    /* auto test type for AIFF or RIFF WAVE if not already committed */
+    if(ftype == TYPE_EOF)
+    {
+      if (!strncmp(xiff, "FORM", 4))
+        ftype = TYPE_AIFF;
+      else if (!strncmp(xiff, "RIFF", 4))
+        ftype = TYPE_RIFF_WAVE;
+    }
+    if(ftype == TYPE_AIFF)
+    {
+      int wtype;
+      wavhdr = aiff_prochdr(filei, &ftype, &nchan, &datalen, &wtype);
+      if (wavhdr == NULL)
+      {
+        if (wtype == 0)
+          /* the header must have been invalid */
+          usage_exit(1, "input file is not a valid AIFF file\n");
+        else
+          /* the bit depth is unsupported */
+          usage_exit(1, "This AIFF has %d-bit samples, which is currently unsupported\n", wtype);
+        ftype = TYPE_EOF;
+      }
+      else
+      {
+        /* we have a valid AIFF so override anything the user may have said to do with the alignment */
+        nskip = 0;
+      }
+    }
 
     /* define type to be RIFF WAVE if not already committed */
     if(ftype == TYPE_EOF)
@@ -1642,6 +1701,10 @@ StartAgain:
   if(fileo && fileo != stdo)
     fclose(fileo);
 
+  /* make the output file look like the original if possible */
+  if((filei != stdi) && (fileo != stdo))
+    (void) dupfileinfo(filenamei, filenameo);
+
   filei = fileo = 0;
 
   if(!extract && filenamei && filenameo && strcmp(filenameo,minusstr))
@@ -1661,7 +1724,6 @@ StartAgain:
 
   if(SeekTableFile)
   {
-    ulong SHNFileSize = 0;
     ulong SeekTableSize;
     uchar *pSeekTableBuffer;
 
@@ -1740,10 +1802,6 @@ StartAgain:
     fclose(SeekTableFile);
   }
 
-  /* make the compressed file look like the original if possible */
-  if((filei != stdi) && (fileo != stdo) && WriteWaveFile)
-    (void) dupfileinfo(filenamei, filenameo);
-
   if(tmpfilename != NULL)
     free(tmpfilename);
 
